Data directory
==============

This directory contains small data files that are included with the speclite
source code distribution.

Filters
-------

The ``filters`` subdirectory contains tabulated filter response curves.
See the `filter documentation page
<http://speclite.readthedocs.io/en/latest/filters.html>`__ for details.
